<!DOCTYPE gui SYSTEM "kpartgui.dtd">
<gui name="kcharselect" version="4">
<MenuBar>
  <Menu name="edit"><text>&amp;Edit</text>
    <Action name="copy_clip"/>
    <Action name="copy_utf_8"/>
    <Action name="copy_html"/>
    <Action name="from_clip"/>
    <Action name="from_clip_utf8"/>
    <Separator/>
    <Action name="flip"/>
    <Action name="rtl"/>
  </Menu>
  <Menu name="settings"><text>&amp;Settings</text>
    <Action name="colorscheme_menu"/>
  </Menu>
 <Action name="bookmarks" />
</MenuBar>
<ToolBar name="mainToolBar" hidden="true">
  <text>Main Toolbar</text>
</ToolBar>
</gui>
